/****************************************************************************
** Meta object code from reading C++ file 'qgstreameraudiodecodersession.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.13)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../git/src/plugins/gstreamer/audiodecoder/qgstreameraudiodecodersession.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qgstreameraudiodecodersession.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.13. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QGstreamerAudioDecoderSession_t {
    QByteArrayData data[20];
    char stringdata0[259];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QGstreamerAudioDecoderSession_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QGstreamerAudioDecoderSession_t qt_meta_stringdata_QGstreamerAudioDecoderSession = {
    {
QT_MOC_LITERAL(0, 0, 29), // "QGstreamerAudioDecoderSession"
QT_MOC_LITERAL(1, 30, 12), // "stateChanged"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 20), // "QAudioDecoder::State"
QT_MOC_LITERAL(4, 65, 8), // "newState"
QT_MOC_LITERAL(5, 74, 13), // "formatChanged"
QT_MOC_LITERAL(6, 88, 12), // "QAudioFormat"
QT_MOC_LITERAL(7, 101, 6), // "format"
QT_MOC_LITERAL(8, 108, 13), // "sourceChanged"
QT_MOC_LITERAL(9, 122, 5), // "error"
QT_MOC_LITERAL(10, 128, 11), // "errorString"
QT_MOC_LITERAL(11, 140, 11), // "bufferReady"
QT_MOC_LITERAL(12, 152, 22), // "bufferAvailableChanged"
QT_MOC_LITERAL(13, 175, 9), // "available"
QT_MOC_LITERAL(14, 185, 8), // "finished"
QT_MOC_LITERAL(15, 194, 15), // "positionChanged"
QT_MOC_LITERAL(16, 210, 8), // "position"
QT_MOC_LITERAL(17, 219, 15), // "durationChanged"
QT_MOC_LITERAL(18, 235, 8), // "duration"
QT_MOC_LITERAL(19, 244, 14) // "updateDuration"

    },
    "QGstreamerAudioDecoderSession\0"
    "stateChanged\0\0QAudioDecoder::State\0"
    "newState\0formatChanged\0QAudioFormat\0"
    "format\0sourceChanged\0error\0errorString\0"
    "bufferReady\0bufferAvailableChanged\0"
    "available\0finished\0positionChanged\0"
    "position\0durationChanged\0duration\0"
    "updateDuration"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QGstreamerAudioDecoderSession[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x06 /* Public */,
       5,    1,   67,    2, 0x06 /* Public */,
       8,    0,   70,    2, 0x06 /* Public */,
       9,    2,   71,    2, 0x06 /* Public */,
      11,    0,   76,    2, 0x06 /* Public */,
      12,    1,   77,    2, 0x06 /* Public */,
      14,    0,   80,    2, 0x06 /* Public */,
      15,    1,   81,    2, 0x06 /* Public */,
      17,    1,   84,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      19,    0,   87,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    9,   10,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   13,
    QMetaType::Void,
    QMetaType::Void, QMetaType::LongLong,   16,
    QMetaType::Void, QMetaType::LongLong,   18,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void QGstreamerAudioDecoderSession::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QGstreamerAudioDecoderSession *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->stateChanged((*reinterpret_cast< QAudioDecoder::State(*)>(_a[1]))); break;
        case 1: _t->formatChanged((*reinterpret_cast< const QAudioFormat(*)>(_a[1]))); break;
        case 2: _t->sourceChanged(); break;
        case 3: _t->error((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 4: _t->bufferReady(); break;
        case 5: _t->bufferAvailableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->finished(); break;
        case 7: _t->positionChanged((*reinterpret_cast< qint64(*)>(_a[1]))); break;
        case 8: _t->durationChanged((*reinterpret_cast< qint64(*)>(_a[1]))); break;
        case 9: _t->updateDuration(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAudioDecoder::State >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAudioFormat >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QGstreamerAudioDecoderSession::*)(QAudioDecoder::State );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGstreamerAudioDecoderSession::stateChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QGstreamerAudioDecoderSession::*)(const QAudioFormat & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGstreamerAudioDecoderSession::formatChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QGstreamerAudioDecoderSession::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGstreamerAudioDecoderSession::sourceChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QGstreamerAudioDecoderSession::*)(int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGstreamerAudioDecoderSession::error)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QGstreamerAudioDecoderSession::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGstreamerAudioDecoderSession::bufferReady)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QGstreamerAudioDecoderSession::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGstreamerAudioDecoderSession::bufferAvailableChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QGstreamerAudioDecoderSession::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGstreamerAudioDecoderSession::finished)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (QGstreamerAudioDecoderSession::*)(qint64 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGstreamerAudioDecoderSession::positionChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (QGstreamerAudioDecoderSession::*)(qint64 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGstreamerAudioDecoderSession::durationChanged)) {
                *result = 8;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QGstreamerAudioDecoderSession::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QGstreamerAudioDecoderSession.data,
    qt_meta_data_QGstreamerAudioDecoderSession,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QGstreamerAudioDecoderSession::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QGstreamerAudioDecoderSession::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QGstreamerAudioDecoderSession.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QGstreamerBusMessageFilter"))
        return static_cast< QGstreamerBusMessageFilter*>(this);
    if (!strcmp(_clname, "org.qt-project.qt.gstreamerbusmessagefilter/5.0"))
        return static_cast< QGstreamerBusMessageFilter*>(this);
    return QObject::qt_metacast(_clname);
}

int QGstreamerAudioDecoderSession::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void QGstreamerAudioDecoderSession::stateChanged(QAudioDecoder::State _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QGstreamerAudioDecoderSession::formatChanged(const QAudioFormat & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QGstreamerAudioDecoderSession::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QGstreamerAudioDecoderSession::error(int _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void QGstreamerAudioDecoderSession::bufferReady()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QGstreamerAudioDecoderSession::bufferAvailableChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void QGstreamerAudioDecoderSession::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QGstreamerAudioDecoderSession::positionChanged(qint64 _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void QGstreamerAudioDecoderSession::durationChanged(qint64 _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
