/****************************************************************************
** Meta object code from reading C++ file 'qvideowidget_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.13)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/multimediawidgets/qvideowidget_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qvideowidget_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.13. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QVideoWidgetBackend_t {
    QByteArrayData data[1];
    char stringdata0[20];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QVideoWidgetBackend_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QVideoWidgetBackend_t qt_meta_stringdata_QVideoWidgetBackend = {
    {
QT_MOC_LITERAL(0, 0, 19) // "QVideoWidgetBackend"

    },
    "QVideoWidgetBackend"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QVideoWidgetBackend[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void QVideoWidgetBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject QVideoWidgetBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QVideoWidgetBackend.data,
    qt_meta_data_QVideoWidgetBackend,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QVideoWidgetBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QVideoWidgetBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QVideoWidgetBackend.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QVideoWidgetControlInterface"))
        return static_cast< QVideoWidgetControlInterface*>(this);
    return QObject::qt_metacast(_clname);
}

int QVideoWidgetBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_QVideoWidgetControlBackend_t {
    QByteArrayData data[1];
    char stringdata0[27];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QVideoWidgetControlBackend_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QVideoWidgetControlBackend_t qt_meta_stringdata_QVideoWidgetControlBackend = {
    {
QT_MOC_LITERAL(0, 0, 26) // "QVideoWidgetControlBackend"

    },
    "QVideoWidgetControlBackend"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QVideoWidgetControlBackend[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void QVideoWidgetControlBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject QVideoWidgetControlBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QVideoWidgetControlBackend.data,
    qt_meta_data_QVideoWidgetControlBackend,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QVideoWidgetControlBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QVideoWidgetControlBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QVideoWidgetControlBackend.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QVideoWidgetControlInterface"))
        return static_cast< QVideoWidgetControlInterface*>(this);
    return QObject::qt_metacast(_clname);
}

int QVideoWidgetControlBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_QRendererVideoWidgetBackend_t {
    QByteArrayData data[16];
    char stringdata0[210];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QRendererVideoWidgetBackend_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QRendererVideoWidgetBackend_t qt_meta_stringdata_QRendererVideoWidgetBackend = {
    {
QT_MOC_LITERAL(0, 0, 27), // "QRendererVideoWidgetBackend"
QT_MOC_LITERAL(1, 28, 17), // "fullScreenChanged"
QT_MOC_LITERAL(2, 46, 0), // ""
QT_MOC_LITERAL(3, 47, 10), // "fullScreen"
QT_MOC_LITERAL(4, 58, 17), // "brightnessChanged"
QT_MOC_LITERAL(5, 76, 10), // "brightness"
QT_MOC_LITERAL(6, 87, 15), // "contrastChanged"
QT_MOC_LITERAL(7, 103, 8), // "contrast"
QT_MOC_LITERAL(8, 112, 10), // "hueChanged"
QT_MOC_LITERAL(9, 123, 3), // "hue"
QT_MOC_LITERAL(10, 127, 17), // "saturationChanged"
QT_MOC_LITERAL(11, 145, 10), // "saturation"
QT_MOC_LITERAL(12, 156, 13), // "formatChanged"
QT_MOC_LITERAL(13, 170, 19), // "QVideoSurfaceFormat"
QT_MOC_LITERAL(14, 190, 6), // "format"
QT_MOC_LITERAL(15, 197, 12) // "frameChanged"

    },
    "QRendererVideoWidgetBackend\0"
    "fullScreenChanged\0\0fullScreen\0"
    "brightnessChanged\0brightness\0"
    "contrastChanged\0contrast\0hueChanged\0"
    "hue\0saturationChanged\0saturation\0"
    "formatChanged\0QVideoSurfaceFormat\0"
    "format\0frameChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QRendererVideoWidgetBackend[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x06 /* Public */,
       4,    1,   52,    2, 0x06 /* Public */,
       6,    1,   55,    2, 0x06 /* Public */,
       8,    1,   58,    2, 0x06 /* Public */,
      10,    1,   61,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      12,    1,   64,    2, 0x08 /* Private */,
      15,    0,   67,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void, QMetaType::Int,   11,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 13,   14,
    QMetaType::Void,

       0        // eod
};

void QRendererVideoWidgetBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QRendererVideoWidgetBackend *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->fullScreenChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->brightnessChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->contrastChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->hueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->saturationChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->formatChanged((*reinterpret_cast< const QVideoSurfaceFormat(*)>(_a[1]))); break;
        case 6: _t->frameChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QRendererVideoWidgetBackend::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QRendererVideoWidgetBackend::fullScreenChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QRendererVideoWidgetBackend::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QRendererVideoWidgetBackend::brightnessChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QRendererVideoWidgetBackend::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QRendererVideoWidgetBackend::contrastChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QRendererVideoWidgetBackend::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QRendererVideoWidgetBackend::hueChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QRendererVideoWidgetBackend::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QRendererVideoWidgetBackend::saturationChanged)) {
                *result = 4;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QRendererVideoWidgetBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QVideoWidgetBackend::staticMetaObject>(),
    qt_meta_stringdata_QRendererVideoWidgetBackend.data,
    qt_meta_data_QRendererVideoWidgetBackend,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QRendererVideoWidgetBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QRendererVideoWidgetBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QRendererVideoWidgetBackend.stringdata0))
        return static_cast<void*>(this);
    return QVideoWidgetBackend::qt_metacast(_clname);
}

int QRendererVideoWidgetBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QVideoWidgetBackend::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void QRendererVideoWidgetBackend::fullScreenChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QRendererVideoWidgetBackend::brightnessChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QRendererVideoWidgetBackend::contrastChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void QRendererVideoWidgetBackend::hueChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void QRendererVideoWidgetBackend::saturationChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
struct qt_meta_stringdata_QWindowVideoWidgetBackend_t {
    QByteArrayData data[1];
    char stringdata0[26];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QWindowVideoWidgetBackend_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QWindowVideoWidgetBackend_t qt_meta_stringdata_QWindowVideoWidgetBackend = {
    {
QT_MOC_LITERAL(0, 0, 25) // "QWindowVideoWidgetBackend"

    },
    "QWindowVideoWidgetBackend"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QWindowVideoWidgetBackend[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void QWindowVideoWidgetBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject QWindowVideoWidgetBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QVideoWidgetBackend::staticMetaObject>(),
    qt_meta_stringdata_QWindowVideoWidgetBackend.data,
    qt_meta_data_QWindowVideoWidgetBackend,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QWindowVideoWidgetBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWindowVideoWidgetBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QWindowVideoWidgetBackend.stringdata0))
        return static_cast<void*>(this);
    return QVideoWidgetBackend::qt_metacast(_clname);
}

int QWindowVideoWidgetBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QVideoWidgetBackend::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
